AdvancedShiftRegister

Struct AdvancedShiftRegister 

pub struct AdvancedShiftRegister<const N: usize, OP: OutputPin> {
    pub shifters: [u8; N],
    /* private fields */
}

Fields

shifters: [u8; N]

Shifter data (currently set bits)

Implementations

Source

impl<const N: usize, OP: OutputPin> AdvancedShiftRegister<N, OP>

pub fn new(data_pin: OP, clk_pin: OP, latch_pin: OP, default_val: u8) -> Self

pub fn get_shifter_mut(&mut self, i: usize) -> ShifterValue

Get wrapper for value of one shifter register (for easy modyfing)

pub fn get_pin_mut(&mut self, i: usize, bit: u8, auto_shift: bool) -> ShifterPin

Get wrapper for one bit of specifed shifter register (with embedded_hal digitalpin trait)

pub fn get_shifter_range_mut( &mut self, range: Range<usize>, ) -> ShifterValueRange

Get wrapper for range of shifter registers (for easy modyfing of multiple registers at the same time)

pub fn update_shifters(&mut self)

Push stored shifters data onto shifter registers